
from .base import VoltageMeasurementDevice

try:
    from .impl.keithley2700 import Keithley2700
except ImportError:
    pass

from .impl.test import TestVoltageMeasurementDevice

def list_devices() -> dict[str,list[str]]:
    devices = {
        "TEST": ["Voltage Measurement Dummy Device"],
    }
    try:
        from .impl import keithley2700
        devices["VISA"] = keithley2700.enumerate_devices()
    except ImportError:
        pass
    return devices

def connect_device(typename: str, devicename: str) -> VoltageMeasurementDevice:
    if typename == "TEST":
        return TestVoltageMeasurementDevice()
    elif typename == "VISA":
        try:
            from .impl import keithley2700
            return keithley2700.init(devicename)
        except ImportError as e:
            raise ValueError(f"VISA devices not available: {e}")
    raise ValueError(f"Unknown device type {typename}")